import { MatrixClient } from "matrix-js-sdk/src/client";
import { ILoginParams, LoginFlow } from "matrix-js-sdk/src/@types/auth";
import { IMatrixClientCreds } from "./MatrixClientPeg";
interface ILoginOptions {
    defaultDeviceDisplayName?: string;
}
export default class Login {
    private hsUrl;
    private isUrl;
    private fallbackHsUrl;
    private flows;
    private defaultDeviceDisplayName;
    private tempClient;
    constructor(hsUrl: string, isUrl: string, fallbackHsUrl?: string, opts?: ILoginOptions);
    getHomeserverUrl(): string;
    getIdentityServerUrl(): string;
    setHomeserverUrl(hsUrl: string): void;
    setIdentityServerUrl(isUrl: string): void;
    /**
     * Get a temporary MatrixClient, which can be used for login or register
     * requests.
     * @returns {MatrixClient}
     */
    createTemporaryClient(): MatrixClient;
    getFlows(): Promise<Array<LoginFlow>>;
    loginViaPassword(username: string, phoneCountry: string, phoneNumber: string, password: string): Promise<IMatrixClientCreds>;
}
/**
 * Send a login request to the given server, and format the response
 * as a MatrixClientCreds
 *
 * @param {string} hsUrl   the base url of the Homeserver used to log in.
 * @param {string} isUrl   the base url of the default identity server
 * @param {string} loginType the type of login to do
 * @param {ILoginParams} loginParams the parameters for the login
 *
 * @returns {IMatrixClientCreds}
 */
export declare function sendLoginRequest(hsUrl: string, isUrl: string, loginType: string, loginParams: ILoginParams): Promise<IMatrixClientCreds>;
export {};
