/// <reference types="node" />
import { MatrixError } from "matrix-js-sdk/src/http-api";
import { MatrixEvent } from "matrix-js-sdk/src/models/event";
import { Optional } from "matrix-events-sdk";
import EventEmitter from "events";
import { MatrixDispatcher } from '../dispatcher/dispatcher';
import { SdkContextClass } from "../contexts/SDKContext";
declare type Listener = (isActive: boolean) => void;
/**
 * A class for storing application state for RoomView.
 */
export declare class RoomViewStore extends EventEmitter {
    private readonly stores;
    private state;
    private dis;
    private dispatchToken;
    constructor(dis: MatrixDispatcher, stores: SdkContextClass);
    addRoomListener(roomId: string, fn: Listener): void;
    removeRoomListener(roomId: string, fn: Listener): void;
    private emitForRoom;
    private setState;
    private doMaybeSetCurrentVoiceBroadcastPlayback;
    private onRoomStateEvents;
    private onDispatch;
    private viewRoom;
    private viewThread;
    private viewRoomError;
    private joinRoom;
    private getInvitingUserId;
    showJoinRoomError(err: MatrixError, roomId: string): void;
    private joinRoomError;
    reset(): void;
    /**
     * Reset which dispatcher should be used to listen for actions. The old dispatcher will be
     * unregistered.
     * @param dis The new dispatcher to use.
     */
    resetDispatcher(dis: MatrixDispatcher): void;
    getRoomId(): Optional<string>;
    getThreadId(): Optional<string>;
    getInitialEventId(): Optional<string>;
    isInitialEventHighlighted(): boolean;
    initialEventScrollIntoView(): boolean;
    getRoomAlias(): Optional<string>;
    isRoomLoading(): boolean;
    getRoomLoadError(): Optional<MatrixError>;
    isJoining(): boolean;
    getJoinError(): Optional<Error>;
    getQuotingEvent(): Optional<MatrixEvent>;
    shouldPeek(): boolean;
    getWasContextSwitch(): boolean;
    isViewingCall(): boolean;
}
export {};
