import { MatrixClient, MatrixEvent } from "matrix-js-sdk/src/matrix";
import { TypedEventEmitter } from "matrix-js-sdk/src/models/typed-event-emitter";
import { SimpleObservable } from "matrix-widget-api";
import { PlaybackInterface, PlaybackState } from "../../audio/Playback";
import { IDestroyable } from "../../utils/IDestroyable";
import { VoiceBroadcastLiveness, VoiceBroadcastInfoState } from "..";
export declare enum VoiceBroadcastPlaybackState {
    Paused = 0,
    Playing = 1,
    Stopped = 2,
    Buffering = 3
}
export declare enum VoiceBroadcastPlaybackEvent {
    PositionChanged = "position_changed",
    LengthChanged = "length_changed",
    LivenessChanged = "liveness_changed",
    StateChanged = "state_changed",
    InfoStateChanged = "info_state_changed"
}
interface EventMap {
    [VoiceBroadcastPlaybackEvent.PositionChanged]: (position: number) => void;
    [VoiceBroadcastPlaybackEvent.LengthChanged]: (length: number) => void;
    [VoiceBroadcastPlaybackEvent.LivenessChanged]: (liveness: VoiceBroadcastLiveness) => void;
    [VoiceBroadcastPlaybackEvent.StateChanged]: (state: VoiceBroadcastPlaybackState, playback: VoiceBroadcastPlayback) => void;
    [VoiceBroadcastPlaybackEvent.InfoStateChanged]: (state: VoiceBroadcastInfoState) => void;
}
export declare class VoiceBroadcastPlayback extends TypedEventEmitter<VoiceBroadcastPlaybackEvent, EventMap> implements IDestroyable, PlaybackInterface {
    readonly infoEvent: MatrixEvent;
    private client;
    private state;
    private chunkEvents;
    private playbacks;
    private currentlyPlaying;
    /** @var total duration of all chunks in milliseconds */
    private duration;
    /** @var current playback position in milliseconds */
    private position;
    readonly liveData: SimpleObservable<number[]>;
    private liveness;
    private infoState;
    private lastInfoEvent;
    private chunkRelationHelper;
    private infoRelationHelper;
    constructor(infoEvent: MatrixEvent, client: MatrixClient);
    private setUpRelationsHelper;
    private addChunkEvent;
    private addInfoEvent;
    private onBeforeRedaction;
    private enqueueChunks;
    private enqueueChunk;
    private onPlaybackPositionUpdate;
    private setDuration;
    private setPosition;
    private onPlaybackStateChange;
    private playNext;
    private playEvent;
    private getPlaybackForEvent;
    getLiveness(): VoiceBroadcastLiveness;
    private setLiveness;
    private updateLiveness;
    get currentState(): PlaybackState;
    get timeSeconds(): number;
    get durationSeconds(): number;
    skipTo(timeSeconds: number): Promise<void>;
    start(): Promise<void>;
    stop(): void;
    pause(): void;
    resume(): void;
    /**
     * Toggles the playback:
     * stopped → playing
     * playing → paused
     * paused → playing
     */
    toggle(): Promise<void>;
    getState(): VoiceBroadcastPlaybackState;
    private setState;
    getInfoState(): VoiceBroadcastInfoState;
    private setInfoState;
    destroy(): void;
}
export {};
